<?php

namespace FiloBlu\CegidY2\Api\SaleDocumentService\EnumType;

/**
 * This class stands for DeliveryType EnumType
 * Meta information extracted from the WSDL
 * - documentation: e-Commerce shipment type
 * - nillable: true
 * - type: tns:DeliveryType
 * @subpackage Enumerations
 */
class DeliveryType
{
    /**
     * Constant for value 'ShipByCentral'
     * Meta information extracted from the WSDL
     * - documentation: Delivery to the customer.
     * @return string 'ShipByCentral'
     */
    const VALUE_SHIP_BY_CENTRAL = 'ShipByCentral';
    /**
     * Constant for value 'BookedInStore'
     * Meta information extracted from the WSDL
     * - documentation: Reservation in store.
     * @return string 'BookedInStore'
     */
    const VALUE_BOOKED_IN_STORE = 'BookedInStore';
    /**
     * Constant for value 'PickingUpInStore'
     * Meta information extracted from the WSDL
     * - documentation: Pick-up in store.
     * @return string 'PickingUpInStore'
     */
    const VALUE_PICKING_UP_IN_STORE = 'PickingUpInStore';
    /**
     * Constant for value 'PickupLocation'
     * Meta information extracted from the WSDL
     * - documentation: Pick-up point.
     * @return string 'PickupLocation'
     */
    const VALUE_PICKUP_LOCATION = 'PickupLocation';
    /**
     * Return true if value is allowed
     * @uses self::getValidValues()
     * @param mixed $value value
     * @return bool true|false
     */
    public static function valueIsValid($value)
    {
        return ($value === null) || in_array($value, self::getValidValues(), true);
    }
    /**
     * Return allowed values
     * @uses self::VALUE_SHIP_BY_CENTRAL
     * @uses self::VALUE_BOOKED_IN_STORE
     * @uses self::VALUE_PICKING_UP_IN_STORE
     * @uses self::VALUE_PICKUP_LOCATION
     * @return string[]
     */
    public static function getValidValues()
    {
        return array(
            self::VALUE_SHIP_BY_CENTRAL,
            self::VALUE_BOOKED_IN_STORE,
            self::VALUE_PICKING_UP_IN_STORE,
            self::VALUE_PICKUP_LOCATION,
        );
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
