<?php

namespace FiloBlu\CegidY2\Api\SaleDocumentService\EnumType;

/**
 * This class stands for PaymentStatus EnumType
 * Meta information extracted from the WSDL
 * - documentation: e-Commerce payment status
 * - nillable: true
 * - type: tns:PaymentStatus
 * @subpackage Enumerations
 */
class PaymentStatus
{
    /**
     * Constant for value 'Pending'
     * Meta information extracted from the WSDL
     * - documentation: Outstanding payment.
     * @return string 'Pending'
     */
    const VALUE_PENDING = 'Pending';
    /**
     * Constant for value 'Totally'
     * Meta information extracted from the WSDL
     * - documentation: Paid.
     * @return string 'Totally'
     */
    const VALUE_TOTALLY = 'Totally';
    /**
     * Constant for value 'Partially'
     * Meta information extracted from the WSDL
     * - documentation: Partially paid.
     * @return string 'Partially'
     */
    const VALUE_PARTIALLY = 'Partially';
    /**
     * Constant for value 'Debited'
     * Meta information extracted from the WSDL
     * - documentation: Payment debited.
     * @return string 'Debited'
     */
    const VALUE_DEBITED = 'Debited';
    /**
     * Constant for value 'PartiallyDebited'
     * Meta information extracted from the WSDL
     * - documentation: Partial payment debited.
     * @return string 'PartiallyDebited'
     */
    const VALUE_PARTIALLY_DEBITED = 'PartiallyDebited';
    /**
     * Constant for value 'CreditIssued'
     * Meta information extracted from the WSDL
     * - documentation: Generated credit note.
     * @return string 'CreditIssued'
     */
    const VALUE_CREDIT_ISSUED = 'CreditIssued';
    /**
     * Constant for value 'CreditRefused'
     * Meta information extracted from the WSDL
     * - documentation: Payment refused.
     * @return string 'CreditRefused'
     */
    const VALUE_CREDIT_REFUSED = 'CreditRefused';
    /**
     * Constant for value 'ToRedeem'
     * Meta information extracted from the WSDL
     * - documentation: To reimburse.
     * @return string 'ToRedeem'
     */
    const VALUE_TO_REDEEM = 'ToRedeem';
    /**
     * Constant for value 'PaymentCredited'
     * Meta information extracted from the WSDL
     * - documentation: Payment credited.
     * @return string 'PaymentCredited'
     */
    const VALUE_PAYMENT_CREDITED = 'PaymentCredited';
    /**
     * Constant for value 'Refunded'
     * Meta information extracted from the WSDL
     * - documentation: Reimbursed.
     * @return string 'Refunded'
     */
    const VALUE_REFUNDED = 'Refunded';
    /**
     * Return true if value is allowed
     * @uses self::getValidValues()
     * @param mixed $value value
     * @return bool true|false
     */
    public static function valueIsValid($value)
    {
        return ($value === null) || in_array($value, self::getValidValues(), true);
    }
    /**
     * Return allowed values
     * @uses self::VALUE_PENDING
     * @uses self::VALUE_TOTALLY
     * @uses self::VALUE_PARTIALLY
     * @uses self::VALUE_DEBITED
     * @uses self::VALUE_PARTIALLY_DEBITED
     * @uses self::VALUE_CREDIT_ISSUED
     * @uses self::VALUE_CREDIT_REFUSED
     * @uses self::VALUE_TO_REDEEM
     * @uses self::VALUE_PAYMENT_CREDITED
     * @uses self::VALUE_REFUNDED
     * @return string[]
     */
    public static function getValidValues()
    {
        return array(
            self::VALUE_PENDING,
            self::VALUE_TOTALLY,
            self::VALUE_PARTIALLY,
            self::VALUE_DEBITED,
            self::VALUE_PARTIALLY_DEBITED,
            self::VALUE_CREDIT_ISSUED,
            self::VALUE_CREDIT_REFUSED,
            self::VALUE_TO_REDEEM,
            self::VALUE_PAYMENT_CREDITED,
            self::VALUE_REFUNDED,
        );
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
